@@ -14,7 +14,7 @@ from requests.models import Request
 from localstack import config
 from localstack.config import ServiceProviderConfig
 from localstack.utils.bootstrap import get_enabled_apis, is_api_enabled, log_duration
-from localstack.utils.common import poll_condition
+from localstack.utils.common import poll_condition, wait_for_port_status
 
 # set up logger
 LOG = logging.getLogger(__name__)
@@ -22,6 +22,8 @@ LOG = logging.getLogger(__name__)
 # namespace for AWS provider plugins
 PLUGIN_NAMESPACE = "localstack.aws.provider"
 
+_default = object()  # sentinel object indicating a default value
+
 
 # ---------------------------
 # STATE SERIALIZER INTERFACE
@@ -116,11 +118,11 @@ class ServiceStateException(ServiceException):
 
 
 class Service(object):
-    def __init__(self, name, start, check=None, listener=None, active=False, stop=None):
+    def __init__(self, name, start, check=_default, listener=None, active=False, stop=None):
         self.plugin_name = name
         self.start_function = start
         self.listener = listener
-        self.check_function = check
+        self.check_function = check if check is not _default else local_api_checker(name)
         self.default_active = active
         self.stop_function = stop
 
@@ -420,6 +422,9 @@ class ServicePluginManager(ServiceManager):
         self._api_provider_specs = None
         self.provider_config = provider_config or config.SERVICE_PROVIDER_CONFIG
 
+    def get_active_provider(self, service: str) -> str:
+        return self.provider_config.get_provider(service)
+
     # TODO make the abstraction clearer, to provide better information if service is available versus discoverable
     # especially important when considering pro services
     def list_available(self) -> List[str]:
@@ -430,7 +435,7 @@ class ServicePluginManager(ServiceManager):
         return [
             service
             for service, providers in self.api_provider_specs.items()
-            if self.provider_config.get_provider(service) in providers
+            if self.get_active_provider(service) in providers
         ]
 
     def exists(self, name: str) -> bool:
@@ -446,7 +451,8 @@ class ServicePluginManager(ServiceManager):
             return None
 
         # if a PluginSpec exists, then we can get the container and check whether there was an error loading the plugin
-        if self.plugin_errors.has_errors(name):
+        provider = self.get_active_provider(name)
+        if self.plugin_errors.has_errors(name, provider):
             return ServiceState.ERROR
 
         return ServiceState.AVAILABLE
@@ -492,7 +498,7 @@ class ServicePluginManager(ServiceManager):
             # no providers for this api
             return None
 
-        preferred_provider = self.provider_config.get_provider(name)
+        preferred_provider = self.get_active_provider(name)
         if preferred_provider in providers:
             provider = preferred_provider
         else:
@@ -505,9 +511,10 @@ class ServicePluginManager(ServiceManager):
             return None
 
         plugin_name = f"{name}:{provider}"
-        service = self.plugin_manager.load(plugin_name)
+        plugin = self.plugin_manager.load(plugin_name)
+        plugin.name = plugin_name
 
-        return service
+        return plugin
 
     @log_duration()
     def _resolve_api_provider_specs(self) -> Dict[str, List[str]]:
@@ -558,23 +565,6 @@ class ServicePluginManager(ServiceManager):
 SERVICE_PLUGINS: ServicePluginManager = ServicePluginManager()
 
 
-# -------------------------
-# HEALTH CHECK API METHODS
-# -------------------------
-
-
-def get_services_health(reload=False):
-    if reload:
-        SERVICE_PLUGINS.check_all()
-
-    result = {
-        "services": {
-            service: state.value for service, state in SERVICE_PLUGINS.get_states().items()
-        }
-    }
-    return result
-
-
 # -----------------------------
 # INFRASTRUCTURE HEALTH CHECKS
 # -----------------------------
@@ -602,3 +592,32 @@ def check_service_health(api, expect_shutdown=False):
         else:
             LOG.warning('Service "%s" still shutting down, retrying...', api)
         raise Exception("Service check failed for api: %s" % api)
+
+
+def local_api_checker(service: str) -> Callable:
+    """
+    Creates a health check method for the given service that works under the assumption that the real backend service
+    ports are locatable through the PROXY_LISTENER global.
+    """
+    from localstack.services.infra import PROXY_LISTENERS
+
+    if config.EAGER_SERVICE_LOADING:
+        # most services don't have a real health check, and if they would, that would dramatically increase the
+        # startup time, since health checks are done sequentially at startup. however, the health checks are needed
+        # for the lazy-loading cold start.
+        return lambda *args, **kwargs: None
+
+    def _check(expect_shutdown=False, print_error=False):
+        try:
+            if service not in PROXY_LISTENERS:
+                LOG.debug("cannot find backend port for service %s", service)
+                return
+            port = PROXY_LISTENERS[service][1]
+
+            LOG.debug("checking service health %s:%d", service, port)
+            wait_for_port_status(port, expect_success=not expect_shutdown)
+        except Exception:
+            if print_error:
+                LOG.exception("service health check %s:%d failed", service, port)
+
+    return _check
