@@ -17,15 +17,15 @@ class ProxyListenerStepFunctions(ProxyListener):
     def return_response(self, method, path, data, headers, response):
         data = json.loads(to_str(data or "{}"))
         name = data.get("name") or (data.get("stateMachineArn") or "").split(":")[-1]
-        target = headers.get("X-Amz-Target")
+        target = headers.get("X-Amz-Target", "").split(".")[-1]
 
         # publish event
-        if target == "AWSStepFunctions.CreateStateMachine":
+        if target == "CreateStateMachine":
             event_publisher.fire_event(
                 event_publisher.EVENT_STEPFUNCTIONS_CREATE_SM,
                 payload={"m": event_publisher.get_hash(name)},
             )
-        elif target == "AWSStepFunctions.DeleteStateMachine":
+        elif target == "DeleteStateMachine":
             event_publisher.fire_event(
                 event_publisher.EVENT_STEPFUNCTIONS_DELETE_SM,
                 payload={"m": event_publisher.get_hash(name)},
