@@ -22,7 +22,7 @@ import time
 import uuid
 import zipfile
 from contextlib import closing
-from datetime import date, datetime, timezone
+from datetime import date, datetime, timezone, tzinfo
 from multiprocessing.dummy import Pool
 from queue import Queue
 from typing import Any, Callable, Dict, List, Optional, Sized, Type, Union
@@ -750,7 +750,7 @@ def to_unique_items_list(inputs, comparator=None):
     return result
 
 
-def timestamp(time=None, format=TIMESTAMP_FORMAT):
+def timestamp(time=None, format: str = TIMESTAMP_FORMAT) -> str:
     if not time:
         time = datetime.utcnow()
     if isinstance(time, six.integer_types + (float,)):
@@ -758,13 +758,13 @@ def timestamp(time=None, format=TIMESTAMP_FORMAT):
     return time.strftime(format)
 
 
-def timestamp_millis(time=None):
+def timestamp_millis(time=None) -> str:
     microsecond_time = timestamp(time=time, format=TIMESTAMP_FORMAT_MICROS)
     # truncating microseconds to milliseconds, while leaving the "Z" indicator
     return microsecond_time[:-4] + microsecond_time[-1]
 
 
-def epoch_timestamp():
+def epoch_timestamp() -> float:
     return time.time()
 
 
@@ -888,11 +888,11 @@ def snake_to_camel_case(string, capitalize_first=True):
     return "".join(components)
 
 
-def base64_to_hex(b64_string):
+def base64_to_hex(b64_string: str) -> bytes:
     return binascii.hexlify(base64.b64decode(b64_string))
 
 
-def obj_to_xml(obj):
+def obj_to_xml(obj) -> str:
     """Return an XML representation of the given object (dict, list, or primitive).
     Does NOT add a common root element if the given obj is a list.
     Does NOT work for nested dict structures."""
@@ -903,18 +903,18 @@ def obj_to_xml(obj):
     return str(obj)
 
 
-def now(millis=False, tz=None):
+def now(millis: bool = False, tz: Optional[tzinfo] = None) -> int:
     return mktime(datetime.now(tz=tz), millis=millis)
 
 
-def now_utc(millis=False):
+def now_utc(millis: bool = False) -> int:
     return now(millis, timezone.utc)
 
 
-def mktime(ts, millis=False):
+def mktime(ts: datetime, millis: bool = False) -> int:
     if millis:
-        return ts.timestamp() * 1000
-    return ts.timestamp()
+        return int(ts.timestamp() * 1000)
+    return int(ts.timestamp())
 
 
 def mkdir(folder):
@@ -922,7 +922,18 @@ def mkdir(folder):
         os.makedirs(folder, exist_ok=True)
 
 
-def ensure_readable(file_path, default_perms=None):
+def is_empty_dir(directory: str, ignore_hidden: bool = False) -> bool:
+    """Return whether the given directory contains any entries (files/folders), including hidden
+    entries whose name starts with a dot (.), unless ignore_hidden=True is passed."""
+    if not os.path.isdir(directory):
+        raise Exception(f"Path is not a directory: {directory}")
+    entries = os.listdir(directory)
+    if ignore_hidden:
+        entries = [e for e in entries if not e.startswith(".")]
+    return not bool(entries)
+
+
+def ensure_readable(file_path: str, default_perms: int = None):
     if default_perms is None:
         default_perms = 0o644
     try:
@@ -1067,11 +1078,23 @@ def format_bytes(count, default="n/a"):
     return count
 
 
+def get_proxies() -> Dict[str, str]:
+    proxy_map = {}
+    if config.OUTBOUND_HTTP_PROXY:
+        proxy_map["http"] = config.OUTBOUND_HTTP_PROXY
+    if config.OUTBOUND_HTTPS_PROXY:
+        proxy_map["https"] = config.OUTBOUND_HTTPS_PROXY
+    return proxy_map
+
+
 def download(url: str, path: str, verify_ssl=True):
     """Downloads file at url to the given path"""
     # make sure we're creating a new session here to
     # enable parallel file downloads during installation!
     s = requests.Session()
+    proxies = get_proxies()
+    if proxies:
+        s.proxies.update(proxies)
     # Use REQUESTS_CA_BUNDLE path. If it doesn't exist, use the method provided settings.
     # Note that a value that is not False, will result to True and will get the bundle file.
     r = s.get(url, stream=True, verify=os.getenv("REQUESTS_CA_BUNDLE", verify_ssl))
@@ -1740,7 +1763,7 @@ def run_for_max_seconds(max_secs, _function, *args, **kwargs):
         time.sleep(0.5)
 
 
-def do_run(cmd: str, run_cmd: Callable, cache_duration_secs: int):
+def do_run(cmd: str, run_cmd: Callable, cache_duration_secs: float):
     if cache_duration_secs <= 0:
         return run_cmd()
 
@@ -1750,7 +1773,7 @@ def do_run(cmd: str, run_cmd: Callable, cache_duration_secs: int):
     if os.path.isfile(cache_file):
         # check file age
         mod_time = os.path.getmtime(cache_file)
-        time_now = now()
+        time_now = time.time()
         if mod_time > (time_now - cache_duration_secs):
             with open(cache_file) as fd:
                 return fd.read()
